@@ -1,5 +1,6 @@
 mod delete_image;
 mod favorite_image;
+mod generate_access_token;
 mod get_account;
 mod get_image;
 mod list_account_images;
@@ -8,6 +9,7 @@ mod upload_image;
 
 pub use delete_image::*;
 pub use favorite_image::*;
+pub use generate_access_token::*;
 pub use get_account::*;
 pub use get_image::*;
 pub use list_account_images::*;
